@@ -1,11 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 #
-# Copyright (c) 2012-2021 Snowflake Computing Inc. All right reserved.
+# Copyright (c) 2012-2021 Snowflake Computing Inc. All rights reserved.
 #
 
-"""This module contains Snowflake error codes."""
+from __future__ import annotations
 
 # network
 ER_FAILED_TO_CONNECT_TO_DB = 250001
@@ -29,6 +27,8 @@ ER_NO_PASSWORD = 251006
 ER_INVALID_VALUE = 251007
 ER_INVALID_PRIVATE_KEY = 251008
 ER_NO_HOSTNAME_FOUND = 251009
+ER_JWT_RETRY_EXPIRED = 251010
+ER_CONNECTION_TIMEOUT = 251011
 
 # cursor
 ER_FAILED_TO_REWRITE_MULTI_ROW_INSERT = 252001
@@ -44,8 +44,6 @@ ER_CHUNK_DOWNLOAD_FAILED = 252010
 ER_NOT_IMPLICITY_SNOWFLAKE_DATATYPE = 252011
 ER_FAILED_PROCESSING_QMARK = 252012
 
-# sfdatetime
-
 # file_transfer
 ER_INVALID_STAGE_FS = 253001
 ER_FAILED_TO_DOWNLOAD_FROM_STAGE = 253002
@@ -57,8 +55,6 @@ ER_COMPRESSION_NOT_SUPPORTED = 253007
 ER_INTERNAL_NOT_MATCH_ENCRYPT_MATERIAL = 253008
 ER_FAILED_TO_CHECK_EXISTING_FILES = 253009
 
-# chunk_downloader
-
 # ocsp
 ER_OCSP_URL_INFO_MISSING = 254001
 ER_OCSP_RESPONSE_UNAVAILABLE = 254002
